@@ -3,10 +3,8 @@ from pdfstream.parsers.ciffile import cif_to_dict
 from pdfstream.parsers.fitdata import dict_to_array, dicts_to_array
 from pdfstream.parsers.fitrecipe import recipe_to_dict
 
-__all__ = [
-    "recipe_to_dict",
-    "dict_to_atoms",
-    "cif_to_dict",
-    "dict_to_array",
-    "dicts_to_array"
-]
+dict_to_atoms = dict_to_atoms
+cif_to_dict = cif_to_dict
+dict_to_array = dict_to_array
+dicts_to_array = dicts_to_array
+recipe_to_dict = recipe_to_dict
